@@ -36,4 +36,7 @@ end
 if nargout>=1
 varargout{1}=RGBcolors;
 end
+if nargout==2
+varargout{2}=h;
+end
 end
